/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
 *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 *
 *  Copyright (C) 2010 Brian Aker
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef PLUGIN_INFORMATION_SCHEMA_DICTIONARY_INFORMATION_SCHEMA_H
#define PLUGIN_INFORMATION_SCHEMA_DICTIONARY_INFORMATION_SCHEMA_H

class InformationSchema : public drizzled::plugin::TableFunction
{
public:

  InformationSchema(const char *table_arg) :
    drizzled::plugin::TableFunction("INFORMATION_SCHEMA", table_arg)
  { }

  class Generator : public drizzled::plugin::TableFunction::Generator 
  {
  public:
    Generator(drizzled::Field **arg):
      drizzled::plugin::TableFunction::Generator(arg)
    { }

    void pushType(drizzled::message::Table::Field::FieldType type);
  };

  Generator *generator(drizzled::Field **arg)
  {
    return new Generator(arg);
  }

};

#endif /* PLUGIN_INFORMATION_SCHEMA_DICTIONARY_INFORMATION_SCHEMA_H */
